# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from Common import *
import Terms

class CurrentHTData:
    def __init__(self):
        self.htdata = None

current_htdata = CurrentHTData()

# This is uses current_htdata and is just a short for lots of lambdas.
def add_currency(amount_of_money, alwaysSign=False):
    lid = current_htdata.htdata.get_section("basics").leagueID
    (htname, name, currency, is_prefix, exchangerate, flag) = country_info[lid]
    return add_currency_to_money(amount_of_money, currency, is_prefix, alwaysSign)

# data_info structure:
# {section: {data_name: (hrf_name, description, convert_func, display_func), ...}, ...}
#
# section: Corresponding to the section of the hrf file.
# data_name: The name of the attribute in the resulting structure.
# hrf_name: The name of the attribute in the hrf file.
#
# Those below might be None, which means that they aren't used.
#
# description: A descritpion of the attribute intended to be read by the users.
# convert_func: A function to convert the value into the correct format.
# display_func: A function to convert the value into a user readable form.

known_general_data_info = {

    "arena":
    {'antalSitt': ('antalSitt', 'Sittplatser', int, None),
     'antalStaplats': ('antalStaplats', 'Stplatser', int, None),
     'antalTak': ('antalTak', 'Stolar under tak', int, None),
     'antalVIP': ('antalVIP', 'Platser i VIP-boxar', int, None),
     'arenaname': ('arenaname', 'Arenanamn', None, None),
     'expandingSitt': ('expandingSitt', 'Expansion av sittplatser', int, None),
     'expandingStaplats': ('expandingStaplats', 'Expansion av stplatser', int, None),
     'expandingTak': ('expandingTak', 'Expansion av stolar under tak', int, None),
     'expandingVIP': ('expandingVIP', 'Expansion av platser i VIP-boxar', int, None),
     'isExpanding': ('isExpanding', 'Under utbyggnad', int, dict2func(Terms.expanding)),
     'seatTotal': ('seatTotal', 'Total kapacitet', int, None)},

    "basics":
    {'application': ('application', None, None, None),
     'appversion': ('appversion', None, None, None),
     'countryID': ('countryID', 'Land', int, (lambda cid: country_info[Terms.country[cid]][1])),
     'date': ('date', 'Datum', string2time, mktimestring),
     'leagueID': ('leagueID', 'Liga', int, (lambda lid: country_info[lid][1])),
     'matchround': ('matchround', 'Omgng', int, None),
     'owner': ('owner', 'gare', None, None),
     'ownerEmail': ('ownerEmail', 'garens epostaddress', None, None),
     'ownerHomepage': ('ownerHomepage', 'garens hemsida', None, None),
     'ownerICQ': ('ownerICQ', 'garens ICQ', None, None),
     'season': ('season', 'Ssong', int, None),
     'teamID': ('teamID', 'Lagets ID', int, None),
     'teamName': ('teamName', 'Lagets namn', None, None)},

    "club":
    {'ekonom': ('ekonom', 'Ekonomer', int, None),
     'fanclub': ('fanclub', 'Supportrar', int, None),
     'hjTranare': ('hjTranare', 'Hjlptrnare', int, None),
     'juniorverksamhet': ('juniorverksamhet', 'Juniorverksamhet', int, None),
     'lakare': ('lakare', 'Lkare', int, None),
     'massor': ('massor', 'Massrer', int, None),
     'mvTranare': ('mvTranare', 'Mlvaktstrnare', int, None),
     'presstalesman': ('presstalesman', 'Presstalesmn', int, None),
     'psykolog': ('psykolog', 'Psykologer', int, None),
     'undefeated': ('undefeated', 'Obesegrade', int, None),
     'victories': ('victories', 'Segrar', int, None)},

    "economy":
    {'IncomeSponsorer': ('IncomeSponsorer', 'Sponsorintkter', int, add_currency),
     'cash': ('cash', 'Pengar', int, add_currency),
     'costsArena': ('costsArena', 'Arenakostnader', int, add_currency),
     'costsJuniorverksamhet': ('costsJuniorverksamhet', 'Kostnader fr juniorverksamhet', int, add_currency),
     'costsPersonal': ('costsPersonal', 'Personalkostnader', int, add_currency),
     'costsRantor': ('costsRantor', 'Rnteutgifter', int, add_currency),
     'costsSpelare': ('costsSpelare', 'Spelarlner', int, add_currency),
     'costsSumma': ('costsSumma', 'Summa utgifter', int, add_currency),
     'costsTillfalliga': ('costsTillfalliga', 'Tillflliga kostnader', int, add_currency),
     'incomeFinansiella': ('incomeFinansiella', 'Finansiella inkomster', int, add_currency),
     'incomePublik': ('incomePublik', 'Publikintkter', int, add_currency),
     'incomeSumma': ('incomeSumma', 'Summa inkomster', int, add_currency),
     'incomeTillfalliga': ('incomeTillfalliga', 'Tillflliga inkomster', int, add_currency),
     'lastCostsArena': ('lastCostsArena', 'Frra veckans arenakostnader', int, add_currency),
     'lastCostsJuniorverksamhet': ('lastCostsJuniorverksamhet', 'Frra veckans kostnader fr juniorverksamhet', int, add_currency),
     'lastCostsPersonal': ('lastCostsPersonal', 'Frra veckans personalkostnader', int, add_currency),
     'lastCostsRantor': ('lastCostsRantor', 'Frra veckans rnteutgifter', int, add_currency),
     'lastCostsSpelare': ('lastCostsSpelare', 'Frra veckans spelarlner', int, add_currency),
     'lastCostsSumma': ('lastCostsSumma', 'Summa frra veckans utgifer', int, add_currency),
     'lastCostsTillfalliga': ('lastCostsTillfalliga', 'Frra veckans tillflliga kostnader', int, add_currency),
     'lastIncomeFinansiella': ('lastIncomeFinansiella', 'Frra veckans finansiella inkomster', int, add_currency),
     'lastIncomePublik': ('lastIncomePublik', 'Frra veckans publikintkter', int, add_currency),
     'lastIncomeSponsorer': ('lastIncomeSponsorer', 'Frra veckans sponsorintkter', int, add_currency),
     'lastIncomeSumma': ('lastIncomeSumma', 'Summa frra veckans inkomster', int, add_currency),
     'lastIncomeTillfalliga': ('lastIncomeTillfalliga', 'Frra veckans tillflliga inkomster', int, add_currency),
     'lastTotal': ('lastTotal', 'Frra veckans resultat', int, add_currency),
     'sponsors': ('sponsors', 'Sponsorer', int, dict2func(Terms.sponsors_and_supporters)),
     'supporters': ('supporters', 'Supportrar', int, dict2func(Terms.sponsors_and_supporters)),
     'total': ('total', 'Resultat', int, add_currency)},

    "league":
    {'gjorda': ('gjorda', 'Gjorda ml', int, None),
     'inslappta': ('inslappta', 'Inslppta ml', int, None),
     'placering': ('placering', 'Placering', int, None),
     'poang': ('poang', 'Pong', int, None),
     'serie': ('serie', 'Serie', None, None),
     'spelade': ('spelade', 'Spelade matcher', int, None)},

    "lineup":
    {'behForward1': ('behForward1', 'Instllning Forward 1', int, dict2func(Terms.individual_order)),
     'behForward2': ('behForward2', 'Instllning Forward 2', int, dict2func(Terms.individual_order)),
     'behInsideBack1': ('behInsideBack1', 'Instllning Innerback 1', int, dict2func(Terms.individual_order)),
     'behInsideBack2': ('behInsideBack2', 'Instllning Innerback 2', int, dict2func(Terms.individual_order)),
     'behInsideMid1': ('behInsideMid1', 'Instllning Innermitt 1', int, dict2func(Terms.individual_order)),
     'behInsideMid2': ('behInsideMid2', 'Instllning Innermitt 2', int, dict2func(Terms.individual_order)),
     'behLeftBack': ('behLeftBack', 'Instllning Vnsterback', int, dict2func(Terms.individual_order)),
     'behLeftWinger': ('behLeftWinger', 'Instllning Vnsterytter', int, dict2func(Terms.individual_order)),
     'behRightBack': ('behRightBack', 'Instllning Hgerback', int, dict2func(Terms.individual_order)),
     'behRightWinger': ('behRightWinger', 'Instllning Hgerytter', int, dict2func(Terms.individual_order)),
     'captain': ('captain', 'Lagkapten', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'forward1': ('forward1', 'Forward 1', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'forward2': ('forward2', 'Forward 2', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'insideBack1': ('insideBack1', 'Innerback 1', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'insideBack2': ('insideBack2', 'Innerback 2', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'insideMid1': ('insideMid1', 'Innermitt 1', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'insideMid2': ('insideMid2', 'Innermitt 2', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'installning': ('installning', 'Instllning', int, dict2func(Terms.attitude)),
     'keeper': ('keeper', 'Mlvakt', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'kicker1': ('kicker1', 'Frisparkslggare', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'leftBack': ('leftBack', 'Vnsterback', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'leftWinger': ('leftWinger', 'Vnsterytter', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'rightBack': ('rightBack', 'Hgerback', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'rightWinger': ('rightWinger', 'Hgerytter', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substBack': ('substBack', 'Avbytare Back', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substForward': ('substForward', 'Avbytare Forward', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substInsideMid': ('substInsideMid', 'Avbytare Innermitt', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substKeeper': ('substKeeper', 'Avbytare mlvakt', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'substWinger': ('substWinger', 'Avbytare ytter', int, (lambda pid: current_htdata.htdata.get_player(pid).name)),
     'trainer': ('trainer', 'Trnare', int, (lambda pid: current_htdata.htdata.get_player(pid).name))},

    "team":
    {'exper343': ('exper343', 'Erfarenhet av 3-4-3', int, dict2func(Terms.formation_experience)),
     'exper352': ('exper352', 'Erfarenhet av 3-5-2', int, dict2func(Terms.formation_experience)),
     'exper433': ('exper433', 'Erfarenhet av 4-3-3', int, dict2func(Terms.formation_experience)),
     'exper451': ('exper451', 'Erfarenhet av 4-5-1', int, dict2func(Terms.formation_experience)),
     'exper532': ('exper532', 'Erfarenhet av 5-3-2', int, dict2func(Terms.formation_experience)),
     'exper541': ('exper541', 'Erfarenhet av 5-4-1', int, dict2func(Terms.formation_experience)),
     'sjalvfortroende': ('sjalvfortroende', 'Sjlvfrtroende', None, None),
     'sjalvfortroendeValue': ('sjalvfortroendeValue', 'Sjlvfrtroende', int, dict2func(Terms.team_self_confidence)),
     'stamning': ('stamning', 'Stmning', None, None),
     'stamningValue': ('stamningValue', 'Stmning', int, dict2func(Terms.team_spirit)),
     'trLevel': ('trLevel', 'Trningsniv', int, (lambda age: str(age) + " %")),
     'trType': ('trType', 'Trningstyp', None, None),
     'trTypeValue': ('trTypeValue', 'Trningstyp', int, dict2func(Terms.training_type))}
    }

known_player_data_info = {
    'Aggressiveness': ('Aggressiveness', 'Aggressivitet', int, dict2func(Terms.aggressiveness)),
    'AggressivenessLabel': ('AggressivenessLabel', 'Aggresivitet', None, None),
    'CountryID': ('CountryID', 'Land', int, (lambda cid: country_info[Terms.country[cid]][1])),
    'TrainerSkill': ('TrainerSkill', 'Trnarfrmga', int, dict2func(Terms.coach_skills)),
    'TrainerType': ('TrainerType', 'Trnartyp', int, dict2func(Terms.coach_type)),
    'ald': ('ald', 'lder', int, (lambda age: str(age) + " r")),
    'bac': ('bac', 'Frsvar', int, dict2func(Terms.player_abilities)),
    'fas': ('fas', 'Fasta situationer', int, dict2func(Terms.player_abilities)),
    'for': ('for', 'Form', int, dict2func(Terms.player_abilities)),
    'fra': ('fra', 'Framspel', int, dict2func(Terms.player_abilities)),
    'gentleness': ('gentleness', 'Trevlighet', int, dict2func(Terms.agreeability)),
    'gentlenessLabel': ('gentlenessLabel', 'Trevlighet', None, None),
    'gev': ('gev', 'Tvlingsml totalt', int, (lambda goals: str(goals) + " ml")),
    'gtc': ('gtc', 'Cupml', int, (lambda goals: str(goals) + " ml")),
    'gtl': ('gtl', 'Ligaml', int, (lambda goals: str(goals) + " ml")),
    'gttot': (None, 'Tvlingsml', int, (lambda goals: str(goals) + " ml")),
    'gtt': ('gtt', 'Trningsml', int, (lambda goals: str(goals) + " ml")),
    'hat': ('hat', 'Hattrick', int, (lambda ht: str(ht) + " hattrick")),
    'honesty': ('honesty', 'Hederlighet', int, dict2func(Terms.honesty)),
    'honestyLabel': ('honestyLabel', 'Hederlighet', None, None),
    'led': ('led', 'Ledarskap', int, dict2func(Terms.player_abilities)),
    'mal': ('mal', 'Mlgrare', int, dict2func(Terms.player_abilities)),
    'mkt': ('mkt', 'Marknadsvrde', int, add_currency),
    'mlv': ('mlv', 'Mlvakt', int, dict2func(Terms.player_abilities)),
    'name': ('name', 'Namn', None, None),
    'playerID': (None, 'Spelaridentitet', int, None),
    'rut': ('rut', 'Rutin', int, dict2func(Terms.player_abilities)),
    'sal': ('sal', 'Ln', int, add_currency),
    'ska': ('ska', 'Skada', int, dict2func(Terms.injury)), # Maybe a func for getting images?
    'spe': ('spe', 'Spelupplgg', int, dict2func(Terms.player_abilities)),
    'speciality': ('speciality', 'Specialitet', int, dict2func(Terms.speciality)),
    'specialityLabel': ('specialityLabel', 'Specialitet', None, None),
    'surname': ('name', 'Efternamn', name2surname, None),
    'uth': ('uth', 'Kondition', int, dict2func(Terms.player_abilities)),
    'warnings': ('warnings', 'Varningar', int, None), # Maybe a func for getting images?
    'ytt': ('ytt', 'Ytter', int, dict2func(Terms.player_abilities))}


# country_info : Contains country related information
# leagueID : ( HT-name, local name, currency, is_prefix?, exchange rate related to Sverige, flag name)
country_info = {
    0:  ('Unknown','Unknown','Unknown',False,1,None),
    1:  ('Sverige','Sverige','kr',False,1,'flag_sverige.png'),
    2:  ('England','England','',True,15,'flag_england.png'),
    3:  ('Deutschland','Tyskland','',False,1,'flag_deutschland.png'),
    4:  ('Italia','Italien','',False,1,'flag_italia.png'),
    5:  ('France','Frankrike','',False,1,'flag_france.png'),
    6:  ('Mxico','Mexiko','',False,1,'flag_mexico.png'),
    7:  ('Argentina','Argentina','',False,1,'flag_argentina.png'),
    8:  ('USA','USA','$',True,1,'flag_usa.png'),
    9:  ('Norge','Norge','',False,1,'flag_norge.png'),
    11: ('Danmark','Danmark','kr',False,1,'flag_danmark.png'),
    12: ('Suomi','Finland','',False,1,'flag_suomi.png'),
    14: ('Nederland','Nederlnderna','',False,1,'flag_nederland.png'),
    15: ('Oceania','Oceanien','',False,1, 'flag_oceania.png'),
    16: ('Brasil','Brasilien','',False,1, 'flag_brasil.png'),
    17: ('Canada','Kanada','',False,1, 'flag_canada.png'),
    18: ('Chile','Chile','',False,1, 'flag_chile.png'),
    19: ('Colombia','Colombia','',False,1, 'flag_colombia.png'),
    20: ('India','Indien','',False,1, 'flag_india.png'),
    21: ('Ireland','Irland','',False,1, 'flag_ireland.png'),
    22: ('Nippon','Japan','',False,1,'flag_nippon.png'),
    23: ('Peru','Peru','',False,1, 'flag_peru.png'),
    24: ('Polska','Polen','',False,1, 'flag_polska.png'),
    25: ('Portugal','Portugal','',False,1, 'flag_portugal.png'),
    26: ('Scotland','Skottland','',False,1, 'flag_scotland.png'),
    27: ('South Africa','Sydafrika','',False,1, 'flag_south_africa.png'),
    28: ('Uruguay','Uruguay','',False,1, 'flag_uruguay.png'),
    29: ('Venezuela','Venezuela','',False,1, 'flag_venezuela.png'),
    30: ('South Korea','Sydkorea','',False,1,'flag_south_korea.png'),
    31: ('Prathet Thai','Thailand','',False,1,'flag_prathet_thai.png'),
    32: ('Trkiye','Turkiet','',False,1,'flag_turkiye.png'),
    33: ('Egypt','Egypten','',False,1,'flag_egypt.png'),
    34: ('China','Kina','',False,1,'flag_china.png'),
    35: ('Rossiya','Ryssland','',False,1,'flag_rossiya.png'),
    36: ('Espaa','Spanien','',False,1,'flag_espana.png'),
    37: ('Romnia','Rumnien','',False,1,'flag_romania.png'),
    38: ('Island','Island','kr',False,1,'flag_island.png'),
    39: ('sterreich','sterrike','',False,1,'flag_osterreich.png'),
    44: ('Belgi','Belgien','',False,1,'flag_belgie.png'),
    45: ('Malaysia','Malaysia','',False,1,'flag_malaysia.png'),
    46: ('Schweiz','Schweiz','',False,1,'flag_schweiz.png'),
    47: ('Singapore','Singapore','',False,1,'flag_singapore.png'),
    50: ('Hellas','Grekland','',False,1,'flag_hellas.png'),
    51: ('Magyarorszg','Ungern','',False,1,'flag_hungary.png'),
    52: ('Ceska republik','Tjeckien','',False,1,'flag_ceska.png'),
    53: ('Latvija','Lettland','',False,1,'flag_latvija.png'),
    54: ('Indonesia','Indonesien','',False,1,'flag_indonesia.png'),
    55: ('Pilipinas','Filipinerna','',False,1,'flag_pilipinas.png'),
    56: ('Eesti','Estland','',False,1,'flag_eesti.png'),
    57: ('Srbija i Crna Gora','Serbien och Montenegro','',False,1,'flag_serbia.png'),
    58: ('Hrvatska','Kroatien','',False,1,'flag_hrvatska.png'),
    59: ('Hong Kong','Hong Kong','',False,1,'flag_hong_kong.png'),
    60: ('Taiwan','Taiwan','',False,1,'flag_taiwan.png'),
    61: ('Wales','Wales','',False,1,'flag_wales.png'),
    62: ('Bulgaria','Bulgarien','',False,1,'flag_bulgaria.png'),
    63: ('Israel','Israel','',False,1,'flag_israel.png'),
    64: ('Slovenija','Slovenien','',False,1,'flag_slovenija.png'),
    66: ('Lietuva','Litauen','',False,1,'flag_lietuva.png'),
    67: ('Slovakia','Slovakien','',False,1,'flag_slovakia.png'),
    68: ('Ukraina','Ukraina','',False,1,'flag_ukraina.png'),
    69: ('Bosnia','Bosnien','',False,1,'flag_bosnia.png'),
    70: ('Vietnam','Vietnam','',False,1,'flag_vietnam.png'),
    71: ('Pakistan','Pakistan','',False,1,'flag_pakistan.png')
    }

