# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import DataInfo
import Terms

import operator

from Common import *
from Commonwx import *

from wxPython.wx import *

class LineupCtrl(wxPanel):
    def __init__(self, parent, ID, use_substs, data_type, data, *extra_data):
        wxPanel.__init__(self, parent, ID, style=wxSUNKEN_BORDER)

        self.SetBackgroundColour("#66AA66")
        sizer = wxBoxSizer(wxVERTICAL)

        n_elements = [["keeper"],
                      ["rightBack", "insideBack1", "insideBack2", "leftBack"],
                      ["rightWinger", "insideMid1", "insideMid2", "leftWinger"],
                      ["forward1", "forward2"]]
        if use_substs:
            n_elements += [["kicker1", "substKeeper", "captain"],
                           ["substBack", "substInsideMid", "substForward", "substWinger"]]

        self.all_elements = reduce(operator.add, n_elements)

        self.static_texts = []
        for elements in n_elements:
            hsizer = wxBoxSizer(wxHORIZONTAL)
            for position in elements:
                vsizer = wxBoxSizer(wxVERTICAL)
                behposition = "beh" + position[0].upper() + position[1:]
                description = DataInfo.known_general_data_info["lineup"][position][1] + ":"
                pos_text = ""
                postexts = [(description, False, False), (pos_text, True, True)]
                if DataInfo.known_general_data_info["lineup"].has_key(behposition):
                    postexts.append(("", False, True))
                else:
                    postexts.append((None, False, True))

                savetexts = [position]
                for text, bold, save in postexts:
                    if text != None:
                        stext = wxStaticText(self, -1, text,
                                             style = wxALIGN_CENTRE)
                        if bold:
                            SetTextBold(stext)
                        vsizer.Add(stext, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 1)
                    else:
                        stext = None
                    if save:
                        savetexts.append(stext)
                self.static_texts.append(savetexts)
                hsizer.Add(vsizer, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 5)

            sizer.AddSizer(hsizer, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        self.data = self.__convert_data(data_type, data, *extra_data)
        self.Update()

    def Update(self):
        if self.data == None:
            for position, pos_name, beh in self.static_texts:
                pos_name.SetLabel("")
                if beh != None:
                    beh.SetLabel("")
            return

        for position, pos_name, beh in self.static_texts:
            pname, order, posval = self.data[position]
            if pname == "0":
                pname = ""
            pos_name.SetLabel(pname)
            if beh != None:
                if pname == "":
                    beh.SetLabel("")
                else:
                    if posval != None:
                        order += "   " + posval
                    beh.SetLabel(order)

        self.GetSizer().RecalcSizes()

    def ChangeHRF(self, data_type, data, *extra_data):
        self.data = self.__convert_data(data_type, data, *extra_data)
        self.Update()

    def __convert_data(self, type, data, *extra_data):
        if data == None:
            return None

        if type == "htdata":
            dt = {}
            for position, pos_name, beh in self.static_texts:
                pname = getattr(data.get_section("lineup", True), position)
                order = None
                if beh != None:
                    behposition = "beh" + position[0].upper() + position[1:]
                    order = getattr(data.get_section("lineup", True), behposition)
                dt[position] = (pname, order, None)
            return dt

        if type == "teamselect":
            htdata = extra_data[0]
            dt = {}
            for position, pos_name, beh in self.static_texts:
                pid, val, n, llpos, order_val = data[position]
                pname = htdata.get_player(pid, True).name
                order = None
                if beh != None:
                    order = Terms.individual_order[order_val]
                extra_value = "%.2f (%d)" % (val, n)
                dt[position] = (pname, order, extra_value)
            return dt
