# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import HRFData
import sys
import string

from Common import *
from DataInfo import *

class Listchanges:
    def __init__(self, h1, h2):
        self.h1 = h1
        self.h2 = h2

    def get_player_changes(self):
        res = []

        pids = self.h1.get_pids() + self.h2.get_pids()
        pids_done = []

        for pid in pids:
            if not pid in pids_done:
                pids_done.append(pid)

                has1 = self.h1.has_player(pid)
                has2 = self.h2.has_player(pid)
                if has1 and has2:
                    name = self.h1.get_player(pid).name
                    data = HRFData.compare(self.h1.get_player(pid), \
                                           self.h2.get_player(pid), True)
                elif has1 and not has2:
                    name = self.h1.get_player(pid).name
                    data = "sld eller sparkad"
                elif has2 and not has1:
                    name = self.h2.get_player(pid).name
                    data = "kpt eller junior"
                else:
                    name = "?"
                    data = "Hur sjutton hamnade vi hr?"

                res.append((name, pid, data))
        return res

    def get_section_changes(self):
        res = []
        sections = self.h1.get_section_names() + self.h2.get_section_names()
        sections_done = []

        for section in sections:
            if not section in sections_done:
                sections_done.append(section)

                has1 = self.h1.has_section(section)
                has2 = self.h2.has_section(section)
                if has1 and has2:
                    data = HRFData.compare(self.h1.get_section(section), \
                                           self.h2.get_section(section), True)
                elif has1 and not has2:
                    data = "sektionen har frsvunnit"
                elif has2 and not has1:
                    data = "ny sektion"
                else:
                    data = "Hur sjutton hamnade vi hr?"

                res.append((section, None, data))
        return res

    def get_changes_text(self):
        res = self.get_player_changes()
        res.sort()
        res += self.get_section_changes()
        return self.__make_changes_text(res)

    def __make_changes_text(self, res):
        def max_length(x,y):
            if len(str(x)) < len(str(y)):
                return y
            else:
                return x

        long_name, long_id =  reduce(lambda x,y: (max_length(x[0],y[0]), \
                                                  max_length(x[1],y[1])), res)
        long_name = len(str(long_name))
        long_id = len(str(long_id))

        res_text = ""

        for r in res:
            if len(r[2]) > 0:
                add = ""
                strextra = ""
                if r[1] != None:
                    add = " (" + str(r[1]) + ")"
                if type(r[2]) == str:
                    strextra += " " + r[2]
                res_text += r[0] + add + ":" + strextra + "\n"
                if len(strextra) == 0:
                    dv = r[2].__dict__.items()
                    if r[1] == None:
                        dv = [(known_general_data_info[r[0]][attr][1], value, attr) \
                              for attr,value in dv]
                    else:
                        dv = [(known_player_data_info[attr][1], value, attr) \
                              for attr,value in dv]
                    dv.sort()
                    for description, value, attribute in dv:
                        if description == None:
                            description = attribute
                        if r[1] == None:
                            h1val = getattr(self.h1.get_section(r[0], True), attribute)
                            h2val = getattr(self.h2.get_section(r[0], True), attribute)
                        else:
                            h1val = getattr(self.h1.get_player(r[1], True), attribute)
                            h2val = getattr(self.h2.get_player(r[1], True), attribute)

                        strvalue = str(h1val) + " -> " + str(h2val)
                        if value == "differ":
                            res_text += "\t" + description + ": " + strvalue + "\n"
                        else:
                            res_text += "\t" + description + ": " + signedstr(value) + " (" + strvalue + ")\n"
        return res_text
