# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os, os.path
import time

import HRFData
import AboutPage
import Playerlist
import ComparisonPage
import Fetchdialog
import Fetch
import EconomyPage
import LineupPage
import MatchPrediction
import SummaryPage
import JuniorSpy
import TeamSelectorPage

from wxPython.wx import *
from Columnlists import *
from Common import *
from Commonwx import *

class MainFrame(wxFrame):
    ID_FETCH = 101
    ID_EXIT  = 103
    ID_OPEN = 105

    def __init__(self, parent, ID, title, filename):
        wxFrame.__init__(self, parent, ID, title)

        if filename != None:
            self.default_dir = os.path.dirname(filename)
        else:
            self.default_dir = os.path.realpath(".")
        self.default_pass = None
        self.default_user = None

        menuBar = wxMenuBar()
        menu = wxMenu()
        menu.Append(MainFrame.ID_OPEN, "&Open", "Open a hrf data file")
        menu.Append(MainFrame.ID_FETCH, "&Fetch data", "Fetch data from the hattrick server")
        menu.AppendSeparator()
        menu.Append(MainFrame.ID_EXIT, "E&xit", "Exit Mattricks")
        menuBar.Append(menu, "&File")

        self.SetMenuBar(menuBar)

        sizer = wxBoxSizer(wxVERTICAL)

        notebook = wxNotebook(self, -1)
        nbsizer = wxNotebookSizer(notebook)

        the_pages = [
            ("about", "Mattricks", AboutPage.AboutPage(notebook, -1)),
            ("summary", "versikt", SummaryPage.SummaryPage(notebook, -1, filename)),
            ("player", "Spelarlista",
             Playerlist.PlayerPage(notebook, -1, filename, player_columns)),
            ("goal", "Skytteliga",
             Playerlist.PlayerPage(notebook, -1, filename, goal_columns)),
            ("comparison", "Jmfrelser", ComparisonPage.ComparisonPage(notebook, -1)),
            ("economy", "Ekonomi", EconomyPage.EconomyPage(notebook, -1, filename)),
            ("lineup", "Laguppstllning", LineupPage.LineupPage(notebook, -1, filename)),
            ("lineupselect", "Laguttagning",
             TeamSelectorPage.TeamSelectorPage(notebook, -1, filename)),
            ("prediction", "Matchberkning", MatchPrediction.MatchPrediction(notebook, -1)),
            ]
        self.pages = {}
        for name, descr, page in the_pages:
            notebook.AddPage(page, descr)
            self.pages[name] = page

        sizer.AddSizer(nbsizer, 1, wxEXPAND | wxALL, 0)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        EVT_MENU(self, MainFrame.ID_OPEN, self.OnOpen)
        EVT_MENU(self, MainFrame.ID_FETCH, self.OnFetch)
        EVT_MENU(self, MainFrame.ID_EXIT,  self.OnExit)

    def OnOpen(self, event):
        wildcard = "HRF Files (*.hrf)|*.hrf|" \
                   "All files (*.*)|*.*"

        dlg = wxFileDialog(self, "Vlj fil med hattrickdata", wildcard = wildcard,
                           style = wxOPEN, defaultDir = self.default_dir)
        if dlg.ShowModal() == wxID_OK:
            self.__change_hrf(dlg.GetPath())
        dlg.Destroy()

    def OnFetch(self, event):
        dlg = Fetchdialog.FetchDialog(self, "Ladda ner data",
                                      defaultDir = self.default_dir,
                                      defaultPass = self.default_pass,
                                      defaultUser = self.default_user)
        exit = False
        hrffile = None
        while exit == False:
            err_message = None
            res = dlg.ShowModal()
            if res == wxID_OK:
                (path, loginname, password, juniorspy) = dlg.GetResult()
                pddlg = None
                if len(loginname) == 0 or len(password) == 0:
                    err_message = "Du mste skriva in bde anvndarnamn och lsenord"
                else:
                    pddlg = wxProgressDialog("Fetching hrf-file...",
                                             "Logging in...",
                                             10,
                                             self,
                                             wxPD_APP_MODAL)

                    self.default_user = loginname
                    self.default_pass = password
                    result = Fetch.fetch_hrf(loginname, password, path, pddlg)

                    if result == Fetch.FETCH_ERROR_STRANGE_RESPONSE:
                        err_message = "Konstigt svar frn servern"
                        exit = True
                    elif result == Fetch.FETCH_ERROR_LOGIN_ERROR:
                        err_message = "Misslyckades att logga in, frsk igen!"
                    else:
                        hrffile = result
                        exit = True

                if err_message != None:
                    mdlg = wxMessageDialog(self, err_message,
                                          "Fel", wxOK | wxICON_ERROR)
                    mdlg.ShowModal()
                    mdlg.Destroy()

                if pddlg != None:
                    pddlg.Destroy()

            else:
                 exit = True

        if hrffile != None:
            if juniorspy == True:
                psdlg=JuniorSpy.JuniorSpySelect(self,HRFData.hrfstorage[hrffile])
                psdlg.ShowModal()
            self.__change_hrf(hrffile)
        dlg.Destroy()

    def OnExit(self, event):
        self.Close(true)

    def __change_hrf(self, hrffile):
        HRFData.htdirs.add_from_filename(hrffile)
        for name, page in self.pages.items():
            page.ChangeHRF(hrffile)

class Main(wxApp):
    ID_FRAME = 201
    def __init__(self, filename = None):
        self.initial_file = filename
        wxApp.__init__(self)

    def OnInit(self):
        frame = MainFrame(NULL, Main.ID_FRAME, "Mattricks", self.initial_file)
        #frame.SetSize((800, 600))
        frame.Show(true)

        self.SetTopWindow(frame)
        del self.initial_file
        return true

def main(*hrfs):
    filename = None
    for hrf in hrfs:
        hrf = os.path.realpath(os.path.expanduser(hrf))
        if os.path.isdir(hrf):
            HRFData.htdirs.add_dirs(hrf)
        else:
            HRFData.htdirs.add_from_filename(hrf)
            filename = hrf

    if filename == None:
        filename = HRFData.htdirs.get_from_time(time.time())

    app = Main(filename)
    app.MainLoop()
