# -*- coding: iso-8859-1 -*-

# Mattricks, a free helper program for hattricks players.
# Copyright (C) 2003 Mattricks Team
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import HRFData
import SelectDateMenu
import DataInfo
import Terms

from Common import *
from Commonwx import *

from wxPython.wx import *

class SummaryPage(wxPanel):
    ID_POPUP_MENU    = 241
    ID_DATE_SELECTED = 242

    def __init__(self, parent, ID, filename):
        if filename == None:
            self.htdata = (None, None)
        else:
            self.htdata = (filename, HRFData.hrfstorage[filename])

        wxPanel.__init__(self, parent, ID)

        sizer = wxBoxSizer(wxVERTICAL)
        hsizer = wxBoxSizer(wxHORIZONTAL)

        self.htbutton = wxButton(self, SummaryPage.ID_POPUP_MENU, \
                                 "ndra datum", style = wxBU_EXACTFIT)
        hsizer.Add(self.htbutton, 0, wxALIGN_CENTRE | wxALL, 5)

        self.current_hrf_info = wxStaticText(self, -1, self.__get_current_text())
        hsizer.Add(self.current_hrf_info, 1, wxEXPAND | wxALL, 5)

        sizer.AddSizer(hsizer, 0, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        fsizer = wxFlexGridSizer(cols=2, vgap=5, hgap=10)
        fsizer.AddGrowableCol(1)
        info = [
            ('Lag', self.__get_display_value, ('basics', 'teamName')),
            ('Land', self.__get_display_value, ('basics', 'countryID')),
            ('Arena', self.__get_display_value, ('arena', 'arenaname')),
            ('Ssong', self.__get_display_value, ('basics', 'season')),
            ('Serie', self.__get_display_value, ('league', 'serie')),
            ('Placering', self.__get_league_placement, ()),
            (None, None, None),
            ('Totalt spelarvrde', self.__calc_player_value, ('mkt', False)),
            ('Medel spelarvrde', self.__calc_player_value, ('mkt', True)),
            ('Total spelarln', self.__calc_player_value, ('sal', False)),
            ('Medel spelarln', self.__calc_player_value, ('sal', True)),
            ('Medellder', self.__calc_player_value, ('ald', True)),
            ('Nuvarande form (medel)', self.__calc_player_display_value,
             ('for', True, Terms.player_abilities)),
            ('Rutin (medel)', self.__calc_player_display_value,
             ('rut', True, Terms.player_abilities)),
            ('Antal spelare', self.__calc_player_value, (None, False)),
            ('Antal nationaliteter', self.__calc_nationalities, ()),
            ]
        self.info = []
        for name, func, args in info:
            if name == None:
                fsizer.Add(15,15)
                fsizer.Add(15,15)
            else:
                nametext = wxStaticText(self, -1, name + ":")
                SetTextBold(nametext)
                fsizer.Add(nametext, 1, wxALIGN_LEFT | wxALIGN_BOTTOM | wxALIGN_TOP)
                stext = wxStaticText(self, -1, "                     ")
                fsizer.Add(stext, 1, wxEXPAND | wxALIGN_LEFT | wxALIGN_BOTTOM | wxALIGN_TOP)
                self.info.append((stext, func, args))

        sizer.AddSizer(fsizer, 1, wxEXPAND | wxALIGN_CENTRE | wxALL, 0)

        self.SetSizer(sizer)
        self.SetAutoLayout(True)
        sizer.Fit(self)

        self.Update()

        EVT_BUTTON(self, SummaryPage.ID_POPUP_MENU, self.OnPopupMenu)

    def Update(self):
        if self.htdata==(None,None):
            return
        
        for stext, func, args in self.info:
            stext.SetLabel(str(func(*args)))

        self.GetSizer().RecalcSizes()

    def ChangeHRF(self, hrffile):
        self.htdata = (hrffile, HRFData.hrfstorage[hrffile])
        self.current_hrf_info.SetLabel(self.__get_current_text())
        self.Update()

    def OnPopupMenu(self, event):
        sdmenu = SelectDateMenu.SelectDateMenu(self, SummaryPage.ID_DATE_SELECTED, \
                                               self.htdata[0])
        SelectDateMenu.EVT_DATE_SELECTED(sdmenu, SummaryPage.ID_DATE_SELECTED, \
                                         self.OnDateSelected)
        rect = self.htbutton.GetRect()
        self.PopupMenu(sdmenu, (rect[0], rect[1] + rect[3]))

    def OnDateSelected(self, event):
        self.ChangeHRF(event.GetHRFFile())

    def __get_current_text(self):
        return htdata_text(self.htdata)

    def __get_display_value(self, section, attribute):
        return getattr(self.htdata[1].get_section(section, True), attribute)

    def __get_league_placement(self):
        league = self.htdata[1].get_section("league", True)
        return str(league.placering) + "   " + str(league.spelade) + "   " + \
               str(league.gjorda) + "-" + str(league.inslappta) + "   " + \
               str(league.poang)

    def __calc_player_display_value(self, attribute, average, convertor):
        val = self.__calc_player_value(attribute, average, False)
        return "%s (%.1f)" % (convertor[round(val)], val)

    def __calc_player_value(self, attribute, average, make_str = True):
        coach = self.htdata[1].get_section("lineup").trainer
        sum = 0
        num = 0
        for pid in self.htdata[1].get_pids():
            if pid != coach:
                num += 1
                if attribute != None:
                    sum += getattr(self.htdata[1].get_player(pid), attribute)
        if attribute != None:
            f2=DataInfo.known_player_data_info[attribute][3]
            if average:
                if make_str:
                    return f2(int(round(float(sum)/float(num))))
                else:
                    return float(sum)/float(num)
            else:
                if make_str:
                    return f2(sum)
                else:
                    return sum
        else:
            if make_str:
                return str(num)
            else:
                return num

    def __calc_nationalities(self):
        nationalities = []
        for pid in self.htdata[1].get_pids():
            n = self.htdata[1].get_player(pid).CountryID
            if not n in nationalities:
                nationalities.append(n)
        return str(len(nationalities))
